@@ -3,7 +3,9 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <eom-plugin.h>
+#include <gtk/gtk.h>
+#include <libpeas/peas-extension-base.h>
+#include <libpeas/peas-object-module.h>
 
 G_BEGIN_DECLS
 
@@ -32,7 +34,11 @@ typedef struct _EomReloadPluginPrivate EomReloadPluginPrivate;
 typedef struct _EomReloadPlugin EomReloadPlugin;
 
 struct _EomReloadPlugin {
-	EomPlugin parent_instance;
+	PeasExtensionBase parent_instance;
+
+	GtkWidget *window;
+	GtkActionGroup *ui_action_group;
+	guint ui_id;
 };
 
 /*
@@ -41,16 +47,16 @@ struct _EomReloadPlugin {
 typedef struct _EomReloadPluginClass EomReloadPluginClass;
 
 struct _EomReloadPluginClass {
-	EomPluginClass parent_class;
+	PeasExtensionBaseClass parent_class;
 };
 
 /*
  * Public methods
  */
-GType eom_reload_plugin_get_type(void) G_GNUC_CONST;
+GType eom_reload_plugin_get_type (void) G_GNUC_CONST;
 
 /* All the plugins must implement this function */
-G_MODULE_EXPORT GType register_eom_plugin(GTypeModule* module);
+G_MODULE_EXPORT void peas_register_types (PeasObjectModule *module);
 
 G_END_DECLS
 
