@@ -33,11 +33,6 @@
 #include "eom-close-confirmation-dialog.h"
 #include <eom-window.h>
 
-#if GTK_CHECK_VERSION (3, 2, 0)
-#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
-#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
-#endif
-
 /* Properties */
 enum 
 {
@@ -397,23 +392,16 @@ build_single_img_dialog (EomCloseConfirmationDialog *dlg)
 	img = EOM_IMAGE (dlg->priv->unsaved_images->data);
 
 	/* Image */
-	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, 
+	image = gtk_image_new_from_icon_name ("dialog-warning",
 					  GTK_ICON_SIZE_DIALOG);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_widget_set_valign (image, GTK_ALIGN_START);
-#else
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-#endif
 
 	/* Primary label */
 	primary_label = gtk_label_new (NULL);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_max_width_chars (GTK_LABEL (primary_label), 88);
 	gtk_label_set_xalign (GTK_LABEL (primary_label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.0, 0.5);
-#endif
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
 	image_name = eom_image_get_caption (img);
@@ -432,19 +420,15 @@ build_single_img_dialog (EomCloseConfirmationDialog *dlg)
 	secondary_label = gtk_label_new (str);
 	g_free (str);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (secondary_label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0.0, 0.5);
-#endif
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
 
-	hbox = gtk_hbox_new (FALSE, 12);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
 
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
-	vbox = gtk_vbox_new (FALSE, 12);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
 	
 	gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
 
@@ -529,7 +513,6 @@ create_treeview (EomCloseConfirmationDialogPrivate *priv)
 	GtkTreeViewColumn *column;
 
 	treeview = gtk_tree_view_new ();
-	gtk_widget_set_size_request (treeview, 260, 120);
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview), FALSE);
 	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview), FALSE);
 
@@ -595,33 +578,26 @@ build_multiple_imgs_dialog (EomCloseConfirmationDialog *dlg)
 
 	priv = dlg->priv;
 
-	hbox = gtk_hbox_new (FALSE, 12);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
   	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))), 
 			    hbox, TRUE, TRUE, 0);
 
 	/* Image */
-	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, 
+	image = gtk_image_new_from_icon_name ("dialog-warning",
 					  GTK_ICON_SIZE_DIALOG);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_widget_set_valign (image, GTK_ALIGN_START);
-#else
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-#endif
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
-	vbox = gtk_vbox_new (FALSE, 12);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
 	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 
 	/* Primary label */
 	primary_label = gtk_label_new (NULL);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_max_width_chars (GTK_LABEL (primary_label), 88);
 	gtk_label_set_xalign (GTK_LABEL (primary_label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.0, 0.5);
-#endif
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
 	str = g_strdup_printf (
@@ -639,18 +615,14 @@ build_multiple_imgs_dialog (EomCloseConfirmationDialog *dlg)
 	g_free (markup_str);
 	gtk_box_pack_start (GTK_BOX (vbox), primary_label, FALSE, FALSE, 0);
 	
-	vbox2 = gtk_vbox_new (FALSE, 8);
+	vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
 	gtk_box_pack_start (GTK_BOX (vbox), vbox2, FALSE, FALSE, 0);
 
 	select_label = gtk_label_new_with_mnemonic (_("S_elect the images you want to save:"));
 
 	gtk_box_pack_start (GTK_BOX (vbox2), select_label, FALSE, FALSE, 0);
 	gtk_label_set_line_wrap (GTK_LABEL (select_label), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (select_label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (select_label), 0.0, 0.5);
-#endif
 
 	scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
 	gtk_box_pack_start (GTK_BOX (vbox2), scrolledwindow, TRUE, TRUE, 0);
@@ -662,6 +634,7 @@ build_multiple_imgs_dialog (EomCloseConfirmationDialog *dlg)
 
 	treeview = create_treeview (priv);
 	gtk_container_add (GTK_CONTAINER (scrolledwindow), treeview);
+	gtk_widget_set_size_request (scrolledwindow, 260, 120);
 
 	/* Secondary label */
 	secondary_label = gtk_label_new (_("If you don't save, "
@@ -669,11 +642,7 @@ build_multiple_imgs_dialog (EomCloseConfirmationDialog *dlg)
 
 	gtk_box_pack_start (GTK_BOX (vbox2), secondary_label, FALSE, FALSE, 0);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (secondary_label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0, 0.5);
-#endif
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (select_label), treeview);
