@@ -53,7 +53,7 @@ eom_util_show_help (const gchar *section, GtkWindow *parent)
 	if (section)
 		uri = g_strdup_printf ("help:eom/%s", section);
 
-	gtk_show_uri (NULL, ((uri != NULL) ? uri : "help:eom"),
+	gtk_show_uri_on_window (parent, ((uri != NULL) ? uri : "help:eom"),
 		      gtk_get_current_event_time (), &error);
 
 	g_free (uri);
